@@ -1,5 +1,7 @@
-__version__ = '0.1.9'
+__version__ = '0.1.11'
 
 from .image import put_qiniu, url_to_array
 from .image import file_to_array
-from .image import url_to_file
\ No newline at end of file
+from .image import url_to_file
+from .image import file_to_file
+from .image import put_file_to_qiniu
\ No newline at end of file
