@@ -9,23 +9,37 @@ from PIL import Image
 import requests 
 from urllib import parse
 
+
+def put_file_to_qiniu(filepath,
+                      access_key:str, 
+                      secret_key:str,
+                      domain:str,
+                      bucket:str):
+    q = qiniu.Auth(access_key, secret_key)
+    token = q.upload_token(bucket)
+    with open(filepath, "rb") as f:
+        subfix = filepath.split(".")[-1]
+        upname = f"{hashlib.md5(f.read()).hexdigest()}.{subfix}"
+        ret, info = qiniu.put_file(token,upname,filepath)
+        key = ret['key']
+        base_url = f'{domain}/{key}'
+        private_url = q.private_download_url(base_url, expires=3600)
+        return private_url
+    return None
+
 def put_qiniu(np,
         access_key:str, 
         secret_key:str,
         domain:str,
         bucket:str):
     q = qiniu.Auth(access_key, secret_key)
-    token = q.upload_token(bucket)
     img = imagetool.array_to_img(np)
     data = img.tobytes()
     key = f"{hashlib.md5(data).hexdigest()}.png"
     img.save(key)
-    ret, info = qiniu.put_file(token,key,key) 
+    url = put_file_to_qiniu(key,access_key,secret_key,domain,bucket)
     os.remove(key)
-    key = ret['key']
-    base_url = f'{domain}/{key}'
-    private_url = q.private_download_url(base_url, expires=3600)
-    return private_url
+    return url
 
 
 
@@ -51,4 +65,9 @@ def url_to_file(url,filepath = None):
         p = parse.urlparse(url)
         filepath = p.path[1:]
     i = Image.fromarray(d,"RGB")
-    i.save(filepath)
\ No newline at end of file
+    i.save(filepath)
+
+def file_to_file(filepath, newpath):
+    d = file_to_array(filepath)
+    i = imagetool.array_to_img(d)
+    i.save(newpath)
\ No newline at end of file
